@@ -219,6 +219,13 @@ test('show good error message for invalid arg', async t => {
   })
 })
 
+test('get node id', async t => {
+  const sg = parse('console.log(123)')
+  const nodeWithPattern = sg.root().find('console.log($$$)')
+  const nodeWithKind = sg.root().find(kind('call_expression'))
+  t.is(nodeWithPattern!.id(), nodeWithKind!.id())
+})
+
 test('find in files', async t => {
   let findInFiles = countedPromise(ts.findInFiles)
   await findInFiles({
@@ -365,4 +372,18 @@ test('find rust', async t => {
   })
   t.assert(changed)
   t.assert(num > 0)
-})
\ No newline at end of file
+})
+
+test("find node by range", (t) => {
+  const sg = parse("const message = `This is a multiline message with unicode characters\nÜbergang\nدرود\n🙌\n`;")
+  const node = sg.root().find({
+    rule: {
+      range: {
+        start: { row: 0, column: 16 },
+        end: { row: 4, column: 1 },
+      }
+    }
+  })
+  const byKind = sg.root().find(js.kind("template_string"))
+  t.is(node!.id(), byKind!.id())
+})
