@@ -151,6 +151,19 @@ def test_pattern():
     ))
     assert node == node2
 
+def test_range_rule():
+    node = root.find(range={
+        "start": {"row": 0, "column": 9},
+        "end": {"row": 0, "column": 13},
+    })
+    assert node
+    assert node.text() == "test"
+    node = root.find(range={
+        "start": {"row": 0, "column": 9},
+        "end": {"row": 0, "column": 12},
+    })
+    assert not node
+
 def test_strictness():
     node = root.find(pattern={
         "context": "let b = 456",
